@@ -1,3 +1,6 @@
+from typing import Any
+
+
 class NotRegisteredError(Exception):
     pass
 
@@ -17,3 +20,8 @@ def safe_pop(target: dict, key: str, *more_keys: str):
         if k in target:
             target.pop(k)
     return target
+
+
+def remove_tuple_element(t: tuple, ele: Any) -> tuple:
+    tmp = [e for e in t if e != ele]
+    return tuple(tmp)
